# GPUTOP

A simple real-time GPU monitoring tool for NVIDIA, AMD and Intel GPUs.

## Installation

From pypi:

```sh
pip install gputop
```

Form source:

```sh
pip install git+https://github.com/intexcor/gputop.git
```

## Usage


```sh
gputop
```

Run to get more information
```sh
gputop --help
```

![image](https://github.com/user-attachments/assets/a3eca25c-b64d-4efd-94e2-fb7b3ca1e313)


## Donation
You can support the project with money. This will help you develop better new versions faster.
CloudTips: https://pay.cloudtips.ru/p/315e026f

## Contacts
Telegram - @intexcp
